- **0.8.1** (2025-01-28):
    - migrate to PyPi Trusted Publisher authentication

- **0.8.0** (2025-01-28):
    - allow custom user-agent headers for API queries

- **0.7.3** (2024-05-12):
    - fix configuration file handling

- **0.7.2** (2024-05-06):
    - fix broken local imports

- **0.7.1** (2024-05-06):
    - migrate source repository and build toolchain to GitHub

- **0.7.0** (2024-05-06):
    - migrate to clean pyproject.toml and hatchling
    - change default config file handling
    - rename git default branch

- **0.6.5** (2024-05-06):
    - catch geocoder error

- **0.6.4** (2021-03-16):
    - fix systemd data_files location

- **0.6.3** (2021-03-15):
    - adopted met.no API 2.0
    - changed to PEP517 build

- **0.6.2** (2020-12-04):
    - removed Arch-only AUR PKGBUILD

- **0.6.1** (2020-09-25):
    - fixed Arch PKGBUILD

- **0.6.0** (2020-09-24):
    - changed systemd template to run in user mode
    - corrected typos in README

- **0.5.0** (2020-03-03):
    - (new feature) configurable thresholds for maximum and average precipitation rates

- **0.4.3** (2020-03-01): 
    - (new feature) `verbose` flag to have `wolkenbruch` print its status

- **0.4.2** (2020-02-27):
    - first feature-complete version

- **0.0.1** (2020-02-26): 
    - first test version
